# nonsentence
A Python function / module that generates nonsense sentences under the scheme vowel-consonsant-vowel, with customisable sentence and word length.

## Usage
Install from PyPi (coming soon):
`pip install nonsentence`
```py
import nonsentence
nonsentence.newSentence(minSentenceLength, maxSentenceLength, minWordLength, maxWordLength)
```
### Example
```py
>>> nonsentence.newSentence(5, 20, 3, 10)
'xeratihut lux qihaci def zevepehot piroqihuc tegot wejijiquh tet gaza piqitadu.'
```
